@@ -1,10 +1,13 @@
-// Copyright (c) 2021 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
+// Copyright (c) 2022 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
 
 //! Low-level API functions to execute / register SpringQL from Rust.
 //!
 //! C API and high-level Rust API are provided separately.
 
 mod engine_mutex;
+mod spring_config;
+
+pub use spring_config::*;
 
 use std::sync::Once;
 
@@ -12,14 +15,11 @@ use crate::{
     error::Result,
     pipeline::name::QueueName,
     sql_processor::SqlProcessor,
-    stream_engine::{command::Command, ForeignSinkRow, SqlConvertible, SqlValue},
+    stream_engine::{command::Command, SinkRow, SqlConvertible, SqlValue},
 };
 
 use self::engine_mutex::EngineMutex;
 
-// TODO config
-const N_WORKER_THREADS: usize = 2;
-
 fn setup_logger() {
     static INIT: Once = Once::new();
 
@@ -27,6 +27,7 @@ fn setup_logger() {
         let _ = env_logger::builder()
             .is_test(false) // To enable color. Logs are not captured by test framework.
             .try_init();
+        log_panics::init();
     });
 
     log::info!("setup_logger(): done");
@@ -43,19 +44,19 @@ pub struct SpringPipeline {
 
 /// Row object from an in memory queue.
 #[derive(Debug)]
-pub struct SpringRow(ForeignSinkRow);
+pub struct SpringRow(SinkRow);
 
-impl From<ForeignSinkRow> for SpringRow {
-    fn from(foreign_sink_row: ForeignSinkRow) -> Self {
-        Self(foreign_sink_row)
+impl From<SinkRow> for SpringRow {
+    fn from(sink_row: SinkRow) -> Self {
+        Self(sink_row)
     }
 }
 
 /// Creates and open an in-process stream pipeline.
-pub fn spring_open() -> Result<SpringPipeline> {
+pub fn spring_open(config: SpringConfig) -> Result<SpringPipeline> {
     setup_logger();
 
-    let engine = EngineMutex::new(N_WORKER_THREADS);
+    let engine = EngineMutex::new(&config);
     let sql_processor = SqlProcessor::default();
 
     Ok(SpringPipeline {
@@ -71,12 +72,16 @@ pub fn spring_open() -> Result<SpringPipeline> {
 /// - [SpringError::Sql](crate::error::SpringError::Sql) when:
 ///   - Invalid SQL syntax.
 ///   - Refers to undefined objects (streams, pumps, etc)
+///   - Other semantic errors.
 /// - [SpringError::InvalidOption](crate::error::SpringError::Sql) when:
 ///   - `OPTIONS` in `CREATE` statement includes invalid key or value.
 pub fn spring_command(pipeline: &SpringPipeline, sql: &str) -> Result<()> {
-    let command = pipeline.sql_processor.compile(sql)?;
     let mut engine = pipeline.engine.get()?;
 
+    let command = pipeline
+        .sql_processor
+        .compile(sql, engine.current_pipeline())?;
+
     match command {
         Command::AlterPipeline(c) => engine.alter_pipeline(c),
     }
@@ -90,8 +95,8 @@ pub fn spring_command(pipeline: &SpringPipeline, sql: &str) -> Result<()> {
 ///   - queue named `queue` does not exist.
 pub fn spring_pop(pipeline: &SpringPipeline, queue: &str) -> Result<SpringRow> {
     let mut engine = pipeline.engine.get()?;
-    let foreign_row = engine.pop_in_memory_queue(QueueName::new(queue.to_string()))?;
-    Ok(SpringRow::from(foreign_row))
+    let sink_row = engine.pop_in_memory_queue(QueueName::new(queue.to_string()))?;
+    Ok(SpringRow::from(sink_row))
 }
 
 /// Get an integer column.
