@@ -1,4 +1,4 @@
-// Copyright (c) 2021 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
+// Copyright (c) 2022 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
 
 use std::cmp::Ordering;
 
@@ -6,7 +6,7 @@ use serde::{Deserialize, Serialize};
 
 /// Comparison result of two [SqlValue](crate::SqlValue)s.
 #[derive(Clone, Eq, PartialEq, Hash, Debug, Serialize, Deserialize)]
-pub enum SqlCompareResult {
+pub(crate) enum SqlCompareResult {
     /// v1 = v2
     Eq,
 
@@ -35,3 +35,15 @@ impl From<Ordering> for SqlCompareResult {
         }
     }
 }
+
+/// for partial_cmp
+impl From<Option<Ordering>> for SqlCompareResult {
+    fn from(partial_ord: Option<Ordering>) -> Self {
+        match partial_ord {
+            Some(Ordering::Less) => Self::LessThan,
+            Some(Ordering::Equal) => Self::Eq,
+            Some(Ordering::Greater) => Self::GreaterThan,
+            None => Self::Null,
+        }
+    }
+}
